#
# spec file for package vkbasalt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __builder ninja
Name:           vkbasalt
Version:        0.3.2.9
Release:        bp156.1.3
Summary:        Vulkan post processing layer
License:        Zlib
URL:            https://github.com/DadSchoorse/vkBasalt
Source0:        https://github.com/DadSchoorse/vkBasalt/archive/v%{version}.tar.gz#/vkBasalt-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  glslang-devel
BuildRequires:  libX11-devel
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  spirv-headers
BuildRequires:  spirv-tools
BuildRequires:  vulkan-headers
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc11
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc12
BuildRequires:  gcc12-c++
%endif

%description
vkBasalt is a Vulkan post processing layer to enhance the visual graphics of games.

%prep
%setup -q -n vkBasalt-%{version}

%build
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CC="gcc-11"
export CXX="g++-11"
%else
export CC="gcc-12"
export CXX="g++-12"
%endif
%meson
%meson_build

%install
%meson_install

# Configuration file
install -Dpm0644 config/vkBasalt.conf -t %{buildroot}%{_sysconfdir}/

%files
%license LICENSE
%doc README.md
%{_libdir}/libvkbasalt.so
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/implicit_layer.d
%{_datadir}/vulkan/implicit_layer.d/vkBasalt.json
%config(noreplace) %{_sysconfdir}/vkBasalt.conf

%changelog
* Sun Apr  2 2023 Carsten Ziepke <kieltux@gmail.com>
- update to v0.3.2.9:
  * fixed build with latest Vulkan-Headers
  * fixed crash when destroying VK_NULL_HANDLE instances, devices
    and swapchains (affected mpv)
- Use gcc11-c++ for openSUSE Leap, otherwise temporarily gcc12-c++,
  because build fails with gcc13-c++
* Wed Dec 28 2022 Dirk Müller <dmueller@suse.com>
- update to v0.3.2.8:
  * fixed regression with multiple effects enabled
  * fixed compatibility with newer vkd3d-proton by fixing VK_INCOMPLETE
    handling in vkGetSwapchainImagesKHR
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to v0.3.2.6:
  * Vulkan 1.3 support
* Mon Feb 14 2022 andy great <andythe_great@pm.me>
- Update to version 0.3.2.5.
  * micro optimized some shaders
  * added a new enableOnLaunch config option
  * fixed crash when the swapchain was created before
    vkGetDeviceQueue was called
  * fixed build on gcc12
* Thu Jul 22 2021 andy great <andythe_great@pm.me>
- Update to version 0.3.2.4.
  * Fixed more issues where incorrect engine name would be shown
  * ToGL detection
  * middle-left and middle-right are now options in the position param
  * Fixed issue where vulkan driver version would be incorrect
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 0.3.2.3.
  * New build option to install the library to a private directory.
* Thu Sep 17 2020 andy great <andythe_great@pm.me>
- Initial package release.
- Add vkbasalt-rpmlintrc to fix shlib-policy-name-error.
